@@ -9,6 +9,13 @@ from lintian_brush.control import (
     get_relation,
     update_control,
     )
+from lintian_brush.rules import (
+    check_cdbs,
+    dh_invoke_drop_with,
+    dh_invoke_drop_argument,
+    update_rules,
+    )
+
 
 # TODO(jelmer): Can we get these elsewhere rather than
 # hardcoding them here?
@@ -22,13 +29,18 @@ new_debhelper_compat_version = {
     'stretch': 10,
     }.get(compat_release, MINIMUM_DEBHELPER_VERSION)
 
+
 if os.path.exists('debian/compat'):
     # Package currently stores compat version in debian/compat..
 
     with open('debian/compat', 'r') as f:
         current_debhelper_compat_version = int(f.read().strip())
 
-    if new_debhelper_compat_version >= 11:
+    # debhelper >= 11 supports the magic debhelper-compat build-dependency.
+    # Exclude cdbs, since it only knows to get the debhelper compat version
+    # from debian/compat.
+
+    if new_debhelper_compat_version >= 11 and not check_cdbs():
         # Upgrade to using debhelper-compat, drop debian/compat file.
         os.unlink('debian/compat')
 
@@ -97,6 +109,50 @@ else:
     update_control(source_package_cb=bump_debhelper_compat)
 
 
+# For a list of behavior changes between debhelper compat verisons, see
+# https://manpages.debian.org/testing/debhelper/debhelper.7.en.html#Supported_compatibility_levels
+
+
+def upgrade_to_debhelper_12():
+
+    def cb(line):
+        if line.strip() == b'dh_clean -k':
+            return b'dh_prep'
+        line = line.replace(
+            b'--buildsystem=python_distutils', b'--buildsystem=pybuild')
+        if line.startswith(b'dh_install ') and b'--list-missing' in line:
+            line = dh_invoke_drop_argument(line, b'--list-missing')
+        if line.startswith(b'dh_install ') and b'--fail-missing' in line:
+            line = dh_invoke_drop_argument(line, b'--fail-missing')
+            return [line, b'dh_missing --fail-missing']
+        return line
+
+    update_rules(cb)
+
+
+def upgrade_to_debhelper_11():
+
+    def cb(line):
+        line = dh_invoke_drop_with(line, b'systemd')
+        return line
+
+    update_rules(cb)
+
+
+upgrade_to_debhelper = {
+    11: upgrade_to_debhelper_11,
+    12: upgrade_to_debhelper_12,
+}
+
+
+for version in range(int(str(current_debhelper_compat_version)),
+                     int(str(new_debhelper_compat_version))+1):
+    try:
+        upgrade_to_debhelper[version]()
+    except KeyError:
+        pass
+
+
 if current_debhelper_compat_version < MINIMUM_DEBHELPER_VERSION:
     kind = "deprecated"
     tag = "package-uses-deprecated-debhelper-compat-version"
