@@ -1,7 +1,5 @@
 #!/usr/bin/python3
 from debian.changelog import Version
-from io import StringIO
-import re
 import sys
 
 from lintian_brush.control import (
@@ -9,6 +7,10 @@ from lintian_brush.control import (
     ensure_minimum_version,
     update_control,
     )
+from lintian_brush.rules import (
+    dh_invoke_drop_with,
+    update_rules,
+    )
 
 
 def bump_debhelper(control):
@@ -20,25 +22,14 @@ def bump_debhelper(control):
         "dh-autoreconf")
 
 
-changed = False
-outf = StringIO()
-with open('debian/rules', 'r') as f:
-    for line in f:
-        orig_line = line
-        line = re.sub(" --with[ =]autoreconf( .+|)$", "\\1", line)
-        line = re.sub(" --with[ =]autoreconf,", " --with=", line)
-        line = re.sub(" --with[ =]([^ ]),autoreconf([ ,])", " --with=\\1\\2",
-                      line)
-        if orig_line != line:
-            changed = True
-        outf.write(line)
+def drop_with_autoreconf(line):
+    return dh_invoke_drop_with(line, b'autoreconf')
 
 
+changed = update_rules(drop_with_autoreconf)
 if not changed:
     sys.exit(2)
 
-with open('debian/rules', 'w') as f:
-    f.write(outf.getvalue())
 
 update_control(source_package_cb=bump_debhelper)
 
