@@ -96,6 +96,8 @@ def parse_watch_file(f):
     if continued:
         # Hmm, broken line?
         lines.append(continued)
+    if not lines:
+        return
     if not lines.pop(0).startswith('version='):
         pass  # Hmm, is this actually a real watch file?
     for line in lines:
@@ -180,7 +182,9 @@ def guess_from_package_xml(path, trust_package):
     import xml.etree.ElementTree as ET
     tree = ET.parse(path)
     root = tree.getroot()
-    assert root.tag == 'package'
+    assert root.tag in (
+        'package', '{http://pear.php.net/dtd/package-2.0}package'
+        ), 'root tag is %r' % root.tag
     name_tag = root.find('name')
     if name_tag is not None:
         yield 'Name', name_tag.text, 'certain'
@@ -232,7 +236,7 @@ def guess_from_debian_copyright(path, trust_package):
         except NotMachineReadableError:
             header = None
         except MachineReadableFormatError as e:
-            warn('Error parsing copyright file: %s', e)
+            warn('Error parsing copyright file: %s' % e)
             header = None
         else:
             header = copyright.header
@@ -241,6 +245,10 @@ def guess_from_debian_copyright(path, trust_package):
             yield "Name", header.upstream_name, 'certain'
         if header.upstream_contact:
             yield "Contact", ','.join(header.upstream_contact), 'certain'
+        if header.source:
+            repo_url = guess_repo_from_url(header.source)
+            if repo_url:
+                yield 'Repository', repo_url, 'possible'
         if "X-Upstream-Bugs" in header:
             yield "Bug-Database", header["X-Upstream-Bugs"], 'certain'
         if "X-Source-Downloaded-From" in header:
@@ -266,8 +274,9 @@ def guess_from_meta_json(path, trust_package):
             yield 'Name', data['name'], 'certain'
         if 'resources' in data:
             resources = data['resources']
-            if 'bugtracker' in resources:
+            if 'bugtracker' in resources and 'web' in resources['bugtracker']:
                 yield "Bug-Database", resources["bugtracker"]["web"], 'certain'
+                # TODO(jelmer): Support resources["bugtracker"]["mailto"]
             if 'homepage' in resources:
                 yield "Homepage", resources["homepage"], 'certain'
             if 'repository' in resources:
@@ -376,7 +385,7 @@ def guess_upstream_metadata_items(path, trust_package=False):
         if len(doap_filenames) == 1:
             CANDIDATES.append((doap_filenames[0], guess_from_doap))
         else:
-            warn('More than one doap filename, ignoring all: %r',
+            warn('More than one doap filename, ignoring all: %r' %
                  doap_filenames)
 
     CANDIDATES.extend([
